@@ -2,12 +2,12 @@
 
   """
 
-from src.giteasy.main import get_github_token_pathes
+from src.giteasy.main import get_github_token_json_fp
 from src.giteasy.main import Repo
 
 
 ## test get_github_token_pathes()
-fp = get_github_token_pathes()
+fp = get_github_token_json_fp()
 print(fp)
 
 ## clone a public repo
